@@ -3,11 +3,13 @@
 #
 
 # The following hash values are used:
-#   sign : +,-,NaN,+inf,-inf
-#   _d   : denominator
-#   _n   : numerator (value = _n/_d)
-#   _a   : accuracy
-#   _p   : precision
+
+#          sign : "+", "-", "+inf", "-inf", or "NaN"
+#            _d : denominator
+#            _n : numerator (value = _n/_d)
+#      accuracy : accuracy
+#     precision : precision
+
 # You should not look at the innards of a BigRat - use the methods for this.
 
 package Math::BigRat;
@@ -21,7 +23,7 @@ use Scalar::Util    qw< blessed >;
 
 use Math::BigFloat ();
 
-our $VERSION = '2.002001';
+our $VERSION = '2.003004';
 $VERSION =~ tr/_//d;
 
 our @ISA = qw(Math::BigFloat);
@@ -571,10 +573,10 @@ sub copy {
     $copy->{sign} = $self->{sign};
     $copy->{_d} = $LIB->_copy($self->{_d});
     $copy->{_n} = $LIB->_copy($self->{_n});
-    $copy->{_a} = $self->{_a} if defined $self->{_a};
-    $copy->{_p} = $self->{_p} if defined $self->{_p};
+    $copy->{accuracy} = $self->{accuracy} if defined $self->{accuracy};
+    $copy->{precision} = $self->{precision} if defined $self->{precision};
 
-    #($copy, $copy->{_a}, $copy->{_p})
+    #($copy, $copy->{accuracy}, $copy->{precision})
     #  = $copy->_find_round_parameters(@_);
 
     return $copy;
@@ -601,7 +603,7 @@ sub bnan {
     $self -> {_n}   = $LIB -> _zero();
     $self -> {_d}   = $LIB -> _one();
 
-    ($self, $self->{_a}, $self->{_p})
+    ($self, $self->{accuracy}, $self->{precision})
       = $self->_find_round_parameters(@_);
 
     return $self;
@@ -631,7 +633,7 @@ sub binf {
     $self -> {_n}   = $LIB -> _zero();
     $self -> {_d}   = $LIB -> _one();
 
-    ($self, $self->{_a}, $self->{_p})
+    ($self, $self->{accuracy}, $self->{precision})
       = $self->_find_round_parameters(@_);
 
     return $self;
@@ -656,7 +658,7 @@ sub bone {
     $self -> {_n}   = $LIB -> _one();
     $self -> {_d}   = $LIB -> _one();
 
-    ($self, $self->{_a}, $self->{_p})
+    ($self, $self->{accuracy}, $self->{precision})
       = $self->_find_round_parameters(@_);
 
     return $self;
@@ -678,7 +680,7 @@ sub bzero {
     $self -> {_n}   = $LIB -> _zero();
     $self -> {_d}   = $LIB -> _one();
 
-    ($self, $self->{_a}, $self->{_p})
+    ($self, $self->{accuracy}, $self->{precision})
       = $self->_find_round_parameters(@_);
 
     return $self;
@@ -1727,7 +1729,7 @@ sub bexp {
         $x->bpow($x_org, @params);
     } else {
         # else just round the already computed result
-        delete $x->{_a}; delete $x->{_p};
+        delete $x->{accuracy}; delete $x->{precision};
         # shortcut to not run through _find_round_parameters again
         if (defined $params[0]) {
             $x->bround($params[0], $params[2]); # then round accordingly
@@ -1737,7 +1739,7 @@ sub bexp {
     }
     if ($fallback) {
         # clear a/p after round, since user did not request it
-        delete $x->{_a}; delete $x->{_p};
+        delete $x->{accuracy}; delete $x->{precision};
     }
 
     $x;
@@ -2336,7 +2338,7 @@ sub as_int {
 
     # Copy the remaining instance variables.
 
-    ($y->{_a}, $y->{_p}) = ($x->{_a}, $x->{_p});
+    ($y->{accuracy}, $y->{precision}) = ($x->{accuracy}, $x->{precision});
 
     # Restore upgrading and downgrading.
 
@@ -2365,7 +2367,7 @@ sub as_rat {
 
     # Copy the remaining instance variables.
 
-    ($y->{_a}, $y->{_p}) = ($x->{_a}, $x->{_p});
+    ($y->{accuracy}, $y->{precision}) = ($x->{accuracy}, $x->{precision});
 
     # Restore upgrading and downgrading
 
@@ -2406,7 +2408,7 @@ sub as_float {
 
     # Copy the remaining instance variables.
 
-    ($y->{_a}, $y->{_p}) = ($x->{_a}, $x->{_p});
+    ($y->{accuracy}, $y->{precision}) = ($x->{accuracy}, $x->{precision});
 
     # Restore upgrading and downgrading.
 
